Citing bilby NR
===============

If you have used :code:`bilby_nr` as part of a project that leads to a
scientific publication, please add the following acknowledge statement:

.. code-block:: console

    Some of the results in this paper have been derived using the ``bilby_nr``
    package~\cite{Hoy:2022tst,Hoy:2024vpc}.

The citation in various formats is given below:

.. tabs::

    .. tab:: bibtex

        .. code-block:: bibtex

          @article{Hoy:2022tst,
              author = "Hoy, Charlie",
              title = "{Accelerating multimodel Bayesian inference, model selection, and systematic studies for gravitational wave astronomy}",
              eprint = "2208.00106",
              archivePrefix = "arXiv",
              primaryClass = "gr-qc",
              reportNumber = "LIGO-P2200228",
              doi = "10.1103/PhysRevD.106.083003",
              journal = "Phys. Rev. D",
              volume = "106",
              number = "8",
              pages = "083003",
              year = "2022"
          }

          @article{Hoy:2024vpc,
              author = "Hoy, Charlie and Akcay, Sarp and Mac Uilliam, Jake and Thompson, Jonathan E.",
              title = "{Incorporation of model accuracy in gravitational wave Bayesian inference}",
              eprint = "2409.19404",
              archivePrefix = "arXiv",
              primaryClass = "gr-qc",
              reportNumber = "LIGO-P2400393",
              doi = "10.1038/s41550-025-02579-7",
              journal = "Nature Astron.",
              volume = "9",
              number = "8",
              pages = "1256--1267",
              year = "2025"
          }

    .. tab:: LaTeX (EU)

        .. code-block::

            %\cite{Hoy:2022tst}
            \bibitem{Hoy:2022tst}
            C.~Hoy,
            %``Accelerating multimodel Bayesian inference, model selection, and systematic studies for gravitational wave astronomy,''
            Phys. Rev. D \textbf{106} (2022) no.8, 083003
            doi:10.1103/PhysRevD.106.083003
            [arXiv:2208.00106 [gr-qc]].

            %\cite{Hoy:2024vpc}
            \bibitem{Hoy:2024vpc}
            C.~Hoy, S.~Akcay, J.~Mac Uilliam and J.~E.~Thompson,
            %``Incorporation of model accuracy in gravitational wave Bayesian inference,''
            Nature Astron. \textbf{9} (2025) no.8, 1256-1267
            doi:10.1038/s41550-025-02579-7
            [arXiv:2409.19404 [gr-qc]].

    .. tab:: LaTeX (US)

        .. code-block::

            %\cite{Hoy:2022tst}
            \bibitem{Hoy:2022tst}
            C.~Hoy,
            %``Accelerating multimodel Bayesian inference, model selection, and systematic studies for gravitational wave astronomy,''
            Phys. Rev. D \textbf{106}, no.8, 083003 (2022)
            doi:10.1103/PhysRevD.106.083003
            [arXiv:2208.00106 [gr-qc]].

            %\cite{Hoy:2024vpc}
            \bibitem{Hoy:2024vpc}
            C.~Hoy, S.~Akcay, J.~Mac Uilliam and J.~E.~Thompson,
            %``Incorporation of model accuracy in gravitational wave Bayesian inference,''
            Nature Astron. \textbf{9}, no.8, 1256-1267 (2025)
            doi:10.1038/s41550-025-02579-7
            [arXiv:2409.19404 [gr-qc]].
